@@ -2,21 +2,8 @@ use chrono::{DateTime, Utc};
 use ic_cdk::api::time;
 use ic_cdk::export::candid::{CandidType, Deserialize, Principal};
 use ic_cdk::{caller, print};
-use ic_event_hub_macros::Event;
 use std::time::{Duration, SystemTime, UNIX_EPOCH};
 
-#[derive(Event, CandidType, Deserialize)]
-pub struct VotingPowerUpdateEvent {
-    #[topic]
-    pub voter: Principal,
-    pub new_voting_power: u64,
-}
-
-#[derive(Event, CandidType, Deserialize)]
-pub struct TotalVotingPowerUpdateEvent {
-    pub new_total_voting_power: u64,
-}
-
 #[derive(Clone, PartialEq, Eq, Hash, CandidType, Deserialize)]
 pub struct RemoteCallEndpoint {
     pub canister_id: Principal,
